@@ -10,7 +10,6 @@
 #'
 #' @importFrom utils browseURL
 #' @importFrom shiny actionButton icon observeEvent dialogViewer runGadget stopApp actionLink
-#' @importFrom miniUI miniPage miniContentPanel miniButtonBlock
 #' @importFrom shinyWidgets updateProgressBar progressBar prettyCheckboxGroup updatePrettyCheckboxGroup
 #' @importFrom ggplot2 ggplot_build
 #'
@@ -21,7 +20,7 @@
 #'
 #' ggplot_to_ppt()
 #'
-#' 
+#'
 #'
 #' # Or with an object's name
 #' library(ggplot2)
@@ -29,11 +28,11 @@
 #'   geom_point(aes(Sepal.Length, Sepal.Width))
 #'
 #' ggplot_to_ppt("p")
-#' 
+#'
 #' }
 #'
 ggplot_to_ppt <- function(gg = NULL) {
-  
+
   if (!requireNamespace(package = "rvg"))
     message("Package 'rvg' is required to run this function")
   if (!requireNamespace(package = "officer"))
@@ -67,7 +66,7 @@ ggplot_to_ppt <- function(gg = NULL) {
       ppt <- officer::add_slide(ppt, layout = "Title and Content", master = "Office Theme")
       testgg <- try(invisible(ggplot2::ggplot_build(get(ggg, envir = globalenv()))), silent = TRUE)
       if (!"try-error" %in% class(testgg)) {
-        ppt <- officer::ph_with(ppt, rvg::dml(code = print(get(ggg, envir = globalenv()))), 
+        ppt <- officer::ph_with(ppt, rvg::dml(code = print(get(ggg, envir = globalenv()))),
                                 location = officer::ph_location_type(type = "body"))
       } else {
         warning(paste0("Skipping '", ggg, "' because : ", attr(testgg, "condition")$message))
@@ -79,31 +78,33 @@ ggplot_to_ppt <- function(gg = NULL) {
 
   } else {
 
-    ui <- miniPage(
-      useShinyUtils(),
-      miniContentPanel(
-        prettyCheckboxGroup(
-          inputId = "select_gg", 
-          label = tags$span("ggplot(s) to export ", actionLink(inputId = "all", label = "(select all)")), 
-          choices = ggplots, status = "primary", 
-          icon = icon("check")
-        ),
-        tags$div(
-          id = "ppt-pb", style = "display: none;",
-          progressBar(id = "progress-ppt", value = 0, display_pct = TRUE)
-        )
+    ui <- fillPage(tags$div(
+      class = "esquisse-container",
+      style = "padding: 10px;",
+      html_dependency_esquisse(),
+      prettyCheckboxGroup(
+        inputId = "select_gg",
+        label = tags$span("ggplot(s) to export ", actionLink(inputId = "all", label = "(select all)")),
+        choices = ggplots, status = "primary",
+        icon = icon("check")
       ),
-      miniButtonBlock(
+      tags$div(
+        id = "ppt-pb", 
+        style = "display: none;",
+        progressBar(id = "progress-ppt", value = 0, display_pct = TRUE)
+      ),
+      tags$div(
+        style = "position: fixed; bottom: 10px; right: 10px; left: 10px;",
         actionButton(
           inputId = "export", label = "Export",
           icon = icon("file-powerpoint-o"),
           class = "btn-block btn-primary"
         )
       )
-    )
+    ))
 
     server <- function(input, output, session) {
-      
+
       observeEvent(input$all, {
         updatePrettyCheckboxGroup(
           session = session, inputId = "select_gg", selected = ggplots
@@ -138,7 +139,7 @@ ggplot_to_ppt <- function(gg = NULL) {
             # ppt <- rvg::ph_with_vg(ppt, print(get(ggg, envir = globalenv())), type = "body")
             testgg <- try(invisible(ggplot2::ggplot_build(get(ggg, envir = globalenv()))), silent = TRUE)
             if (!"try-error" %in% class(testgg)) {
-              ppt <- officer::ph_with(ppt, rvg::dml(code = print(get(ggg, envir = globalenv()))), 
+              ppt <- officer::ph_with(ppt, rvg::dml(code = print(get(ggg, envir = globalenv()))),
                                       location = officer::ph_location_type(type = "body"))
             } else {
               warning(paste0("Skipping '", ggg, "' because of : ", attr(testgg, "condition")$message))
